@@ -3,7 +3,7 @@
 ###
 ### oktest.py -- new style test utility
 ###
-### $Release: 0.2.1 $
+### $Release: 0.2.2 $
 ### $Copyright: copyright(c) 2010 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -180,19 +180,21 @@ class ValueObject(object):
                 self.value()
             except:
                 ex = sys.exc_info()[1]
+                self.value.exception = ex
                 if not isinstance(ex, exception_class):
                     self._failed('%s%r is kind of %s' % (ex.__class__.__name__, ex.args, exception_class.__name__), depth=3)
                     #raise
-                if errmsg is None or ex.args[0] == errmsg:
+                if errmsg is None or str(ex) == errmsg:
                     return
                 #self._failed("expected %r but got %r" % (errmsg, ex.message))
-                self._failed("%r == %r" % (ex.args[0], errmsg), depth=3)
+                self._failed("%r == %r" % (str(ex), errmsg), depth=3)
             self._failed('%s should be raised' % exception_class.__name__, depth=3)
         else:
             try:
                 self.value()
             except:
                 ex = sys.exc_info()[1]
+                self.value.exception = ex
                 if isinstance(ex, exception_class):
                     self._failed('%s should not be raised' % exception_class.__name__, depth=3)
 
@@ -377,10 +379,10 @@ class SimpleReporter(BaseReporter):
         OUT.write("".join(self.buf))
 
     def print_ok(self, obj):
-        OUT.write(".")
+        OUT.write("."); OUT.flush()
 
     def print_failed(self, obj, ex):
-        OUT.write("f")
+        OUT.write("f"); OUT.flush()
         self.buf.append("Failed: %s()\n" % self._test_ident(obj))
         self.buf.append("   %s\n" % ex.args[0])
         file, line, text = self._get_location(ex)
@@ -388,7 +390,7 @@ class SimpleReporter(BaseReporter):
             self.buf.append("   %s:%s:  %s\n" % (file, line, text))
 
     def print_error(self, obj, ex):
-        OUT.write('E')
+        OUT.write('E'); OUT.flush()
         self.buf.append("ERROR: %s()\n" % self._test_ident(obj))
         self.buf.append("  %s: %s\n" % (ex.__class__.__name__, str(ex)))
         #traceback.print_exc(file=sys.stdout)
@@ -422,7 +424,7 @@ class OldStyleReporter(BaseReporter):
         OUT.write("[ok]\n")
 
     def print_failed(self, obj, ex):
-        OUT.write("[NG] %s\n" % ex.args[0])
+        OUT.write("[NG] %s\n" % str(ex))
         file, line, text = self._get_location(ex)
         if file:
             OUT.write("   %s:%s: %s\n" % (file, line, text))
